@@ -407,12 +407,12 @@ html5 = HtmlVariant
         , "dfn", "div", "dl", "dt", "em", "fieldset", "figcaption", "figure"
         , "footer", "form", "h1", "h2", "h3", "h4", "h5", "h6", "head", "header"
         , "hgroup", "html", "i", "iframe", "ins", "kbd", "label"
-        , "legend", "li", "map", "mark", "menu", "meter", "nav", "noscript"
-        , "object", "ol", "optgroup", "option", "output", "p", "pre", "progress"
-        , "q", "rp", "rt", "ruby", "samp", "script", "section", "select"
-        , "small", "span", "strong", "style", "sub", "summary", "sup"
-        , "table", "tbody", "td", "textarea", "tfoot", "th", "thead", "time"
-        , "title", "tr", "ul", "var", "video"
+        , "legend", "li", "main", "map", "mark", "menu", "meter", "nav"
+        , "noscript", "object", "ol", "optgroup", "option", "output", "p"
+        , "pre", "progress", "q", "rp", "rt", "ruby", "samp", "script"
+        , "section", "select", "small", "span", "strong", "style", "sub"
+        , "summary", "sup", "table", "tbody", "td", "textarea", "tfoot", "th"
+        , "thead", "time", "title", "tr", "ul", "var", "video"
         ]
     , leafs =
         -- http://www.whatwg.org/specs/web-apps/current-work/multipage/syntax.html#void-elements
